package Data::Filter::Rule::Operation;
use strict;
use warnings;

#*******************************************************************************
# DOCUMENTATION SECTION
#*******************************************************************************

=head1 NAME

Data::Filter::Rule::Operation - Mentat message filter tree base operation node

=head1 SYNOPSIS

 use Data::Filter::Rule::Operation;

=head1 DESCRIPTION



=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1), Data::Filter::Rule(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
# LIBRARY LOADING SECTION
#*******************************************************************************

#-- Perl core modules ---------------------------------------------------------#
use Carp;
use Scalar::Util 'blessed';

#use Data::Dumper; #--- DEVELOPMENT ONLY ---#
#use Smart::Comments; #--- DEVELOPMENT ONLY ---#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Data::Filter::Rule;

#*******************************************************************************
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
# INITIALIZATION AND CLEANUP SECTION
#*******************************************************************************

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL @ISA);
    $VERSION = '0.1';
    $DEVEL   = 0;
    @ISA     = ('Data::Filter::Rule');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
# IMPLEMENTATION SECTION
#*******************************************************************************

=item datatype(;$) [PUBLIC]

  Usage     : my $result = $rule->datatype();
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub datatype(;$)
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);

    return $self->{DATATYPE};
}

=item value($) [PUBLIC]

  Usage     : my $result = $rule->value();
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub value()
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);

    return undef;
}

=item valid_operation($) [PUBLIC]

  Usage     : my $operation = $rule->valid_operation();
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub valid_operation($)
{
    my $self = shift;
    confess "Method needs implementation";
}

=item operation(;$) [PUBLIC]

  Usage     : my $result = $rule->operation();
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub operation(;$)
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);
    my ($operation,) = @_;

    ($self->{OPERATION}, $self->{DATATYPE}) = $self->valid_operation($operation) if ($operation);

    return $self->{OPERATION};
}

=pod

=back

=cut

1;
